Enum Error

#[non_exhaustive]
pub enum Error {
Show 33 variants NetworkContact, GenesisKeyMismatch, CouldNotReadHomeDir, CouldNotCreateSafeDir, ReceivedUnexpectedEvent, NoNetworkKnowledge, IncomingMessages, InsufficientElderConnections { connections: usize, required: usize, }, InsufficientElderKnowledge { connections: usize, required: usize, section_pk: PublicKey, }, PeerConnection(SocketAddr), EmptyFileProvided, TooSmallForSelfEncryption, SmallFilePaddingNeeded, TooLargeAsSmallFile, QueryTimedOut, NoEncryptionObject, NoResponse, UnknownOperationId, UnexpectedQueryResponse(QueryResponse), NetworkDataError(Error), ErrorMsg { source: ErrorMsg, op_id: OperationId, }, ErrorCmd { source: ErrorMsg, msg_id: MsgId, }, MessagingProtocol(Error), SelfEncryption(Error), ConfigError(Error), IoError(Error), EndpointSetup(ClientEndpointError), QuicP2p(RpcError), QuicP2pConnection(ConnectionError), QuicP2pSend(SendError), Serialisation(Box<ErrorKind>), NotEnoughChunksRetrieved { expected: usize, retrieved: usize, }, NotAllDataWasChunked { expected: usize, chunked: usize, },
}
Client Errors

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NetworkContact

Initial network contact failed



GenesisKeyMismatch

Genesis Key from the config and the PrefixMap mismatch



CouldNotReadHomeDir

Error reading home dir for client



CouldNotCreateSafeDir

Error creating root dir for client



ReceivedUnexpectedEvent

Received unexpected event.



NoNetworkKnowledge

Client has not gone through qp2p bootstrap process yet



IncomingMessages

qp2p’s IncomingMessages errores



InsufficientElderConnections

Could not connect to sufficient elder to retrieve reliable responses.

Fields

connections: usize

Number of existing connections to Elders

required: usize

Minimum number of connections to Elders required for the operation



InsufficientElderKnowledge

Did not know of sufficient elders in the desired section to get supermajority of repsonses.

Fields

connections: usize

Number of existing connections to Elders

required: usize

Minimum number of connections to Elders required for the operation

section_pk: PublicKey

Public key of the target section



PeerConnection(SocketAddr)

Peer connection retrieval failed



EmptyFileProvided

Cannot store empty file..



TooSmallForSelfEncryption

Not enough bytes for self-encryption.



SmallFilePaddingNeeded

Encryption oversized the SmallFile, so it cannot be stored as a SmallFile and be encrypted



TooLargeAsSmallFile

The provided bytes is too large to store as a SmallFile.



QueryTimedOut

No query response before timeout



NoEncryptionObject

Could not get an encryption object.



NoResponse

Could not query elder.



UnknownOperationId

No operation Id could be found



UnexpectedQueryResponse(QueryResponse)

Unexpected response received



NetworkDataError(Error)

Other types errors



ErrorMsg

Errors received from the network via sn_messaging

Fields

source: ErrorMsg

The source of an error msg

op_id: OperationId

operation ID that was used to send the query



ErrorCmd

Error response received for a client cmd sent to the network

Fields

source: ErrorMsg

The source of an error msg

msg_id: MsgId

MsgId of the cmd



MessagingProtocol(Error)

Errors occurred when serialising or deserialising msgs



SelfEncryption(Error)

self_enryption errors



ConfigError(Error)

Other types errors



IoError(Error)

Io error.



EndpointSetup(ClientEndpointError)

Endpoint setup error.



QuicP2p(RpcError)

QuicP2p error.



QuicP2pConnection(ConnectionError)

QuicP2p Connection error.



QuicP2pSend(SendError)

QuicP2p Send error.



Serialisation(Box<ErrorKind>)

Bincode error



NotEnoughChunksRetrieved

Could not retrieve all chunks required to decrypt the data. (expected, error)

Fields

expected: usize

Number of Chunks expected to be retrieved

retrieved: usize

Number of Chunks retrieved



NotAllDataWasChunked

Could not chunk all the data required to encrypt the data. (Expected, Actual)

Fields

expected: usize

Number of Chunks expected to be generated

chunked: usize

Number of Chunks generated